Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SmellsEncrypted ¶
SmellsEncrypted - Try to guess if a string is encrypted or not
Types ¶
type APIResponse ¶
APIResponse - Envelope to communicate details to the frontent
type Note ¶
type Note struct {
Content string `json:"content"`
Created string `json:"created"`
Encrypted bool `json:"encrypted"`
Password string `json:"password"`
Subject string `json:"subject"`
Tags string `json:"tags"`
UID string `json:"uid"`
Updated string `json:"updated"`
// Fields largely to support the `-secondary` feature
AheadOfPrimary bool `json:"ahead_of_primary"`
Deleted bool `json:"deleted"`
Time time.Time `json:"time"`
// Private fields
SecondaryPath string `json:"-"`
}
Note represents a single note stored by the application
func Persistable ¶
Persistable prepares a note for being persisted to storage
type TimeSorter ¶
type TimeSorter Notes
TimeSorter sorts notes lines by last updated
func (TimeSorter) Len ¶
func (a TimeSorter) Len() int
func (TimeSorter) Less ¶
func (a TimeSorter) Less(i, j int) bool
func (TimeSorter) Swap ¶
func (a TimeSorter) Swap(i, j int)
Click to show internal directories.
Click to hide internal directories.